==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/kubernetes/api/model/ConfigMapVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class ConfigMapVolumeSourceBuilder extends ConfigMapVolumeSourceFluentImpl<ConfigMapVolumeSourceBuilder> implements VisitableBuilder<ConfigMapVolumeSource,ConfigMapVolumeSourceBuilder>{

    ConfigMapVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public ConfigMapVolumeSourceBuilder(){
            this(true);
    }
    public ConfigMapVolumeSourceBuilder(Boolean validationEnabled){
            this(new ConfigMapVolumeSource(), validationEnabled);
    }
    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSourceFluent<?> fluent){
            this(fluent, true);
    }
    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ConfigMapVolumeSource(), validationEnabled);
    }
    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSourceFluent<?> fluent,ConfigMapVolumeSource instance){
            this(fluent, instance, true);
    }
    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSourceFluent<?> fluent,ConfigMapVolumeSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withItems(instance.getItems()); 
            fluent.withName(instance.getName()); 
            this.validationEnabled = validationEnabled; 
    }
    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSource instance){
            this(instance,true);
    }
    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withItems(instance.getItems()); 
            this.withName(instance.getName()); 
            this.validationEnabled = validationEnabled; 
    }

    public ConfigMapVolumeSource build(){
            ConfigMapVolumeSource buildable = new ConfigMapVolumeSource(fluent.getItems(),fluent.getName());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ConfigMapVolumeSourceBuilder that = (ConfigMapVolumeSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.67-sources.jar: annotations/io/fabric8/kubernetes/api/model/ConfigMapVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ConfigMapVolumeSourceBuilder extends ConfigMapVolumeSourceFluentImpl<ConfigMapVolumeSourceBuilder> implements VisitableBuilder<ConfigMapVolumeSource,ConfigMapVolumeSourceBuilder>{

    ConfigMapVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public ConfigMapVolumeSourceBuilder(){
            this(true);
    }
    public ConfigMapVolumeSourceBuilder(Boolean validationEnabled){
            this(new ConfigMapVolumeSource(), validationEnabled);
    }
    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSourceFluent<?> fluent){
            this(fluent, true);
    }
    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ConfigMapVolumeSource(), validationEnabled);
    }
    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSourceFluent<?> fluent,ConfigMapVolumeSource instance){
            this(fluent, instance, true);
    }
    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSourceFluent<?> fluent,ConfigMapVolumeSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withDefaultMode(instance.getDefaultMode()); 
            fluent.withItems(instance.getItems()); 
            fluent.withName(instance.getName()); 
            this.validationEnabled = validationEnabled; 
    }
    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSource instance){
            this(instance,true);
    }
    public ConfigMapVolumeSourceBuilder(ConfigMapVolumeSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withDefaultMode(instance.getDefaultMode()); 
            this.withItems(instance.getItems()); 
            this.withName(instance.getName()); 
            this.validationEnabled = validationEnabled; 
    }

    public ConfigMapVolumeSource build(){
            ConfigMapVolumeSource buildable = new ConfigMapVolumeSource(fluent.getDefaultMode(),fluent.getItems(),fluent.getName());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ConfigMapVolumeSourceBuilder that = (ConfigMapVolumeSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
